import { match } from "../index";

const tests = [
  {
    input: "Etablissement public de santé",
    expected: "text",
  },
  { input: "Julien", expected: "lastname" },
  { input: "Martin", expected: "lastname" },
  { input: "Céline", expected: "firstname" },
  { input: "Celine", expected: "firstname" },
  { input: "CELINE", expected: "firstname" },
  { input: "mont de marsan", expected: "city" },
  { input: "Larbi", expected: "lastname" },
  { input: "Leila", expected: "firstname" },
  { input: "Henri de la tour", expected: "fullname" },
  { input: "de la verriere", expected: "city" },
  { input: "Emmanuel", expected: "firstname" },
  { input: "Catherine", expected: "firstname" },
  { input: "CATHERINE", expected: "firstname" },
  { input: "Pinard", expected: "lastname" },
  { input: "Pinardo", expected: "lastname" },
  { input: "bouquillon", expected: "lastname" },
  { input: "saint etienne", expected: "city" },
  { input: "saint-etienne", expected: "city" },
  { input: "sens", expected: "city" },
  { input: "pedro", expected: "lastname" },
  { input: "maalik", expected: "firstname" },
  { input: "anderson", expected: "lastname" },
  { input: "Rochefourchat", expected: "text" },
  { input: "cityneuve saint georges", expected: "city" },
  { input: "saint-clement", expected: "city" },
  { input: "paris", expected: "city" },
  { input: "mlle", expected: "title" },
  { input: "Mr", expected: "title" },
  { input: "10/10/2010", expected: "date_fr" },
  { input: "2010-12-31", expected: "date" },
  { input: "2010-12-31T09:00:00", expected: "datetime" },
  { input: "2010-12-31T10:59:46.538Z", expected: "datetime" },
  { input: "Homme", expected: "sex" },
  { input: "75012", expected: "postcode" },
  { input: "89100", expected: "postcode" },
  { input: "2a", expected: "postcode" },
  { input: "test@test.com", expected: "email" },
  { input: "42.765765,4.876875", expected: "geo" },
  { input: "+33 01 4243 43 22", expected: "phone" },
  { input: "+33 1 4243 43 22", expected: "phone" },
  { input: "0142434322", expected: "phone" },
  { input: "1.1.1.1", expected: "ip" },
  { input: "4325", expected: "integer" },
  { input: "1.4325", expected: "float" },
  { input: "1,4325", expected: "float" },
  { input: "123456789", expected: "siren" },
  { input: "12345678900012", expected: "siret" },
  { input: "3, place carnot", expected: "address" },
  { input: "place carnot", expected: "address" },
  { input: "9 Boulevard montparnasse, les mureaux", expected: "address" },
  { input: "78 ter rue des ormes", expected: "address" },
  { input: "un texte quelconque", expected: "text" },
  { input: "http://some.url", expected: "url" },
  { input: "https://some.url/x/y?a=42#some-hash", expected: "url" },
  { input: "Julien Martin", expected: "fullname" },
  { input: "Francois du pont", expected: "fullname" },
  { input: "Francois le ber", expected: "fullname" },
  {
    input:
      "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries",
    expected: "text",
  },
];

tests.forEach((t) => {
  test(`${t.input} should be "${t.expected}"`, async () => {
    const results = await match(t.input);
    expect(results[0].type).toEqual(t.expected);
  });
});
